==> kea-docs-2.0.2-1-aarch64.pkg.tar.xz: usr/share/doc/kea/devel/dir_862598e893fc0f1bed46c00d00206efb.js <==
var dir_862598e893fc0f1bed46c00d00206efb =
[
    [ "encode", "dir_7733e8e5f80aed1c49dfde9511da6b69.html", "dir_7733e8e5f80aed1c49dfde9511da6b69" ],
    [ "io", "dir_7577ca5182f7cc2159e66315e1ae1b2c.html", "dir_7577ca5182f7cc2159e66315e1ae1b2c" ],
    [ "unittests", "dir_b34828d94bbfe33010be8fd57d9b38ae.html", "dir_b34828d94bbfe33010be8fd57d9b38ae" ],
    [ "boost_time_utils.cc", "d6/d98/boost__time__utils_8cc.html", null ],
    [ "boost_time_utils.h", "d9/dd9/boost__time__utils_8h.html", "d9/dd9/boost__time__utils_8h" ],
    [ "buffer.h", "d5/d08/buffer_8h.html", "d5/d08/buffer_8h" ],
    [ "chrono_time_utils.cc", "de/d81/chrono__time__utils_8cc.html", "de/d81/chrono__time__utils_8cc" ],
    [ "chrono_time_utils.h", "d9/d1b/chrono__time__utils_8h.html", "d9/d1b/chrono__time__utils_8h" ],
    [ "csv_file.cc", "d0/d0a/csv__file_8cc.html", "d0/d0a/csv__file_8cc" ],
    [ "csv_file.h", "dd/d62/csv__file_8h.html", "dd/d62/csv__file_8h" ],
    [ "doubles.h", "d3/d20/doubles_8h.html", "d3/d20/doubles_8h" ],
    [ "filename.cc", "de/d86/filename_8cc.html", null ],
    [ "filename.h", "dc/dd6/filename_8h.html", [
      [ "isc::util::Filename", "da/df3/classisc_1_1util_1_1Filename.html", "da/df3/classisc_1_1util_1_1Filename" ]
    ] ],
    [ "hash.h", "db/dfb/hash_8h.html", [
      [ "isc::util::Hash64", "d0/dca/structisc_1_1util_1_1Hash64.html", null ]
    ] ],
    [ "io_utilities.h", "dc/d0a/io__utilities_8h.html", "dc/d0a/io__utilities_8h" ],
    [ "labeled_value.cc", "da/d54/labeled__value_8cc.html", "da/d54/labeled__value_8cc" ],
    [ "labeled_value.h", "db/df6/labeled__value_8h.html", "db/df6/labeled__value_8h" ],
    [ "memory_segment.h", "d8/ded/memory__segment_8h.html", [
      [ "isc::util::MemorySegment", "d2/dcc/classisc_1_1util_1_1MemorySegment.html", "d2/dcc/classisc_1_1util_1_1MemorySegment" ],
      [ "isc::util::MemorySegmentError", "d7/d78/classisc_1_1util_1_1MemorySegmentError.html", "d7/d78/classisc_1_1util_1_1MemorySegmentError" ],
      [ "isc::util::MemorySegmentGrown", "d8/dfb/classisc_1_1util_1_1MemorySegmentGrown.html", "d8/dfb/classisc_1_1util_1_1MemorySegmentGrown" ],
      [ "isc::util::MemorySegmentOpenError", "d3/ddf/classisc_1_1util_1_1MemorySegmentOpenError.html", "d3/ddf/classisc_1_1util_1_1MemorySegmentOpenError" ]
    ] ],
    [ "memory_segment_local.cc", "d3/dfb/memory__segment__local_8cc.html", null ],
    [ "memory_segment_local.h", "dc/d90/memory__segment__local_8h.html", [
      [ "isc::util::MemorySegmentLocal", "d1/d07/classisc_1_1util_1_1MemorySegmentLocal.html", "d1/d07/classisc_1_1util_1_1MemorySegmentLocal" ]
    ] ],
    [ "multi_threading_mgr.cc", "d1/db3/multi__threading__mgr_8cc.html", null ],
    [ "multi_threading_mgr.h", "d6/d13/multi__threading__mgr_8h.html", [
      [ "isc::util::CSCallbackSet", "d5/d82/structisc_1_1util_1_1CSCallbackSet.html", "d5/d82/structisc_1_1util_1_1CSCallbackSet" ],
      [ "isc::util::CSCallbackSetList", "d7/db1/classisc_1_1util_1_1CSCallbackSetList.html", "d7/db1/classisc_1_1util_1_1CSCallbackSetList" ],
      [ "isc::util::MultiThreadingCriticalSection", "d4/d58/classisc_1_1util_1_1MultiThreadingCriticalSection.html", "d4/d58/classisc_1_1util_1_1MultiThreadingCriticalSection" ],
      [ "isc::util::MultiThreadingMgr", "dc/dc9/classisc_1_1util_1_1MultiThreadingMgr.html", "dc/dc9/classisc_1_1util_1_1MultiThreadingMgr" ]
    ] ],
    [ "optional.h", "dc/d62/optional_8h.html", "dc/d62/optional_8h" ],
    [ "pid_file.cc", "d3/dac/pid__file_8cc.html", null ],
    [ "pid_file.h", "de/d6e/pid__file_8h.html", "de/d6e/pid__file_8h" ],
    [ "pointer_util.h", "d5/dc0/pointer__util_8h.html", "d5/dc0/pointer__util_8h" ],
    [ "range_utilities.h", "df/dc1/range__utilities_8h.html", "df/dc1/range__utilities_8h" ],
    [ "readwrite_mutex.h", "da/d35/readwrite__mutex_8h.html", [
      [ "isc::util::ReadLockGuard", "dc/da6/classisc_1_1util_1_1ReadLockGuard.html", "dc/da6/classisc_1_1util_1_1ReadLockGuard" ],
      [ "isc::util::ReadWriteMutex", "d6/df6/classisc_1_1util_1_1ReadWriteMutex.html", "d6/df6/classisc_1_1util_1_1ReadWriteMutex" ],
      [ "isc::util::WriteLockGuard", "d4/de9/classisc_1_1util_1_1WriteLockGuard.html", "d4/de9/classisc_1_1util_1_1WriteLockGuard" ]
    ] ],
    [ "staged_value.h", "d7/df0/staged__value_8h.html", [
      [ "isc::util::StagedValue< ValueType >", "d4/d27/classisc_1_1util_1_1StagedValue.html", "d4/d27/classisc_1_1util_1_1StagedValue" ]
    ] ],
    [ "state_model.cc", "d0/d48/state__model_8cc.html", null ],
    [ "state_model.h", "d2/df8/state__model_8h.html", "d2/df8/state__model_8h" ],
    [ "stopwatch.cc", "d3/d68/stopwatch_8cc.html", null ],
    [ "stopwatch.h", "d5/d4b/stopwatch_8h.html", [
      [ "isc::util::Stopwatch", "d7/da8/classisc_1_1util_1_1Stopwatch.html", "d7/da8/classisc_1_1util_1_1Stopwatch" ]
    ] ],
    [ "stopwatch_impl.cc", "d2/da6/stopwatch__impl_8cc.html", null ],
    [ "stopwatch_impl.h", "d3/d6e/stopwatch__impl_8h.html", [
      [ "isc::util::StopwatchImpl", "dd/dd2/classisc_1_1util_1_1StopwatchImpl.html", "dd/dd2/classisc_1_1util_1_1StopwatchImpl" ]
    ] ],
    [ "strutil.cc", "dc/d73/strutil_8cc.html", "dc/d73/strutil_8cc" ],
    [ "strutil.h", "d6/d23/strutil_8h.html", "d6/d23/strutil_8h" ],
    [ "thread_pool.h", "d3/dec/thread__pool_8h.html", [
      [ "isc::util::ThreadPool< WorkItem, Container >", "d0/db1/structisc_1_1util_1_1ThreadPool.html", "d0/db1/structisc_1_1util_1_1ThreadPool" ]
    ] ],
    [ "time_utilities.cc", "df/d36/time__utilities_8cc.html", "df/d36/time__utilities_8cc" ],
    [ "time_utilities.h", "da/d96/time__utilities_8h.html", "da/d96/time__utilities_8h" ],
    [ "unlock_guard.h", "df/d57/unlock__guard_8h.html", [
      [ "isc::util::UnlockGuard< Mutex >", "d2/ddc/classisc_1_1util_1_1UnlockGuard.html", "d2/ddc/classisc_1_1util_1_1UnlockGuard" ]
    ] ],
    [ "versioned_csv_file.cc", "d0/dea/versioned__csv__file_8cc.html", null ],
    [ "versioned_csv_file.h", "d7/d12/versioned__csv__file_8h.html", "d7/d12/versioned__csv__file_8h" ],
    [ "watch_socket.cc", "d7/de3/watch__socket_8cc.html", null ],
    [ "watch_socket.h", "dd/d83/watch__socket_8h.html", "dd/d83/watch__socket_8h" ],
    [ "watched_thread.cc", "d2/dca/watched__thread_8cc.html", null ],
    [ "watched_thread.h", "da/d8e/watched__thread_8h.html", "da/d8e/watched__thread_8h" ]
];

==> kea-docs-2.2.0-3-aarch64.pkg.tar.xz: usr/share/doc/kea/devel/dir_862598e893fc0f1bed46c00d00206efb.js <==
var dir_862598e893fc0f1bed46c00d00206efb =
[
    [ "encode", "dir_7733e8e5f80aed1c49dfde9511da6b69.html", "dir_7733e8e5f80aed1c49dfde9511da6b69" ],
    [ "io", "dir_7577ca5182f7cc2159e66315e1ae1b2c.html", "dir_7577ca5182f7cc2159e66315e1ae1b2c" ],
    [ "unittests", "dir_b34828d94bbfe33010be8fd57d9b38ae.html", "dir_b34828d94bbfe33010be8fd57d9b38ae" ],
    [ "boost_time_utils.cc", "d6/d98/boost__time__utils_8cc.html", null ],
    [ "boost_time_utils.h", "d9/dd9/boost__time__utils_8h.html", "d9/dd9/boost__time__utils_8h" ],
    [ "buffer.h", "d5/d08/buffer_8h.html", "d5/d08/buffer_8h" ],
    [ "chrono_time_utils.cc", "de/d81/chrono__time__utils_8cc.html", "de/d81/chrono__time__utils_8cc" ],
    [ "chrono_time_utils.h", "d9/d1b/chrono__time__utils_8h.html", "d9/d1b/chrono__time__utils_8h" ],
    [ "csv_file.cc", "d0/d0a/csv__file_8cc.html", "d0/d0a/csv__file_8cc" ],
    [ "csv_file.h", "dd/d62/csv__file_8h.html", "dd/d62/csv__file_8h" ],
    [ "dhcp_space.cc", "dc/d0a/dhcp__space_8cc.html", "dc/d0a/dhcp__space_8cc" ],
    [ "dhcp_space.h", "d1/d1a/dhcp__space_8h.html", "d1/d1a/dhcp__space_8h" ],
    [ "doubles.h", "d3/d20/doubles_8h.html", "d3/d20/doubles_8h" ],
    [ "file_utilities.cc", "df/d2e/file__utilities_8cc.html", "df/d2e/file__utilities_8cc" ],
    [ "file_utilities.h", "d8/de7/file__utilities_8h.html", "d8/de7/file__utilities_8h" ],
    [ "filename.cc", "de/d86/filename_8cc.html", null ],
    [ "filename.h", "dc/dd6/filename_8h.html", "dc/dd6/filename_8h" ],
    [ "hash.h", "db/dfb/hash_8h.html", "db/dfb/hash_8h" ],
    [ "io_utilities.h", "dc/d0a/io__utilities_8h.html", "dc/d0a/io__utilities_8h" ],
    [ "labeled_value.cc", "da/d54/labeled__value_8cc.html", "da/d54/labeled__value_8cc" ],
    [ "labeled_value.h", "db/df6/labeled__value_8h.html", "db/df6/labeled__value_8h" ],
    [ "memory_segment.h", "d8/ded/memory__segment_8h.html", "d8/ded/memory__segment_8h" ],
    [ "memory_segment_local.cc", "d3/dfb/memory__segment__local_8cc.html", null ],
    [ "memory_segment_local.h", "dc/d90/memory__segment__local_8h.html", "dc/d90/memory__segment__local_8h" ],
    [ "multi_threading_mgr.cc", "d1/db3/multi__threading__mgr_8cc.html", null ],
    [ "multi_threading_mgr.h", "d6/d13/multi__threading__mgr_8h.html", "d6/d13/multi__threading__mgr_8h" ],
    [ "optional.h", "dc/d62/optional_8h.html", "dc/d62/optional_8h" ],
    [ "pid_file.cc", "d3/dac/pid__file_8cc.html", null ],
    [ "pid_file.h", "de/d6e/pid__file_8h.html", "de/d6e/pid__file_8h" ],
    [ "pointer_util.h", "d5/dc0/pointer__util_8h.html", "d5/dc0/pointer__util_8h" ],
    [ "range_utilities.h", "df/dc1/range__utilities_8h.html", "df/dc1/range__utilities_8h" ],
    [ "readwrite_mutex.h", "da/d35/readwrite__mutex_8h.html", "da/d35/readwrite__mutex_8h" ],
    [ "reconnect_ctl.cc", "d4/daf/reconnect__ctl_8cc.html", null ],
    [ "reconnect_ctl.h", "d3/dc2/reconnect__ctl_8h.html", "d3/dc2/reconnect__ctl_8h" ],
    [ "staged_value.h", "d7/df0/staged__value_8h.html", "d7/df0/staged__value_8h" ],
    [ "state_model.cc", "d0/d48/state__model_8cc.html", null ],
    [ "state_model.h", "d2/df8/state__model_8h.html", "d2/df8/state__model_8h" ],
    [ "stopwatch.cc", "d3/d68/stopwatch_8cc.html", null ],
    [ "stopwatch.h", "d5/d4b/stopwatch_8h.html", "d5/d4b/stopwatch_8h" ],
    [ "stopwatch_impl.cc", "d2/da6/stopwatch__impl_8cc.html", null ],
    [ "stopwatch_impl.h", "d3/d6e/stopwatch__impl_8h.html", "d3/d6e/stopwatch__impl_8h" ],
    [ "strutil.cc", "dc/d73/strutil_8cc.html", "dc/d73/strutil_8cc" ],
    [ "strutil.h", "d6/d23/strutil_8h.html", "d6/d23/strutil_8h" ],
    [ "thread_pool.h", "d3/dec/thread__pool_8h.html", "d3/dec/thread__pool_8h" ],
    [ "time_utilities.cc", "df/d36/time__utilities_8cc.html", "df/d36/time__utilities_8cc" ],
    [ "time_utilities.h", "da/d96/time__utilities_8h.html", "da/d96/time__utilities_8h" ],
    [ "triplet.h", "d7/d13/triplet_8h.html", "d7/d13/triplet_8h" ],
    [ "unlock_guard.h", "df/d57/unlock__guard_8h.html", "df/d57/unlock__guard_8h" ],
    [ "versioned_csv_file.cc", "d0/dea/versioned__csv__file_8cc.html", null ],
    [ "versioned_csv_file.h", "d7/d12/versioned__csv__file_8h.html", "d7/d12/versioned__csv__file_8h" ],
    [ "watch_socket.cc", "d7/de3/watch__socket_8cc.html", null ],
    [ "watch_socket.h", "dd/d83/watch__socket_8h.html", "dd/d83/watch__socket_8h" ],
    [ "watched_thread.cc", "d2/dca/watched__thread_8cc.html", null ],
    [ "watched_thread.h", "da/d8e/watched__thread_8h.html", "da/d8e/watched__thread_8h" ]
];
